WebContextMenuHelper class

Constructors

WebContextMenuHelper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

disableContextMenu() → void
Disable context menu for the entire page
enableContextMenu() → void
Re-enable context menu for the entire page
temporarilyDisableContextMenu({int durationMs = 500}) → void
Temporarily disable context menu while an action is being performed